/*
 * Copyright 2016-2020 Crown Copyright
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package uk.gov.gchq.gaffer.spark.serialisation;

import com.fasterxml.jackson.core.type.TypeReference;
import org.apache.spark.api.java.JavaRDD;
import org.apache.spark.rdd.RDD;
import org.apache.spark.sql.Dataset;
import org.apache.spark.sql.Row;

import uk.gov.gchq.gaffer.data.element.Element;

/**
 * Spark-specific {@link TypeReference} implementations.
 */
public final class TypeReferenceSparkImpl {
    public static class DataSetRow extends TypeReference<Dataset<Row>> {
    }

    public static class JavaRDDElement extends TypeReference<JavaRDD<Element>> {
    }

    public static class RDDElement extends TypeReference<RDD<Element>> {
    }

    public static class GraphFrame extends TypeReference<org.graphframes.GraphFrame> {
    }

    private TypeReferenceSparkImpl() {
        // Private constructor to prevent instantiation.
    }

    public static class IterableRowT extends TypeReference<Iterable<? extends Row>> {
    }
}
